@@ -41,7 +41,8 @@ LockScreen::LockScreen()
     m_View->setCacheMode(QGraphicsView::CacheBackground);
     m_View->setViewportUpdateMode(QGraphicsView::BoundingRectViewportUpdate);
     m_View->setFrameStyle(QFrame::NoFrame);
-    m_View->setFixedSize(800, 480);
+    m_View->setContentsMargins(0,0,0,0);
+    //m_View->setFixedSize(800, 480);
 
     m_WasPortrait = LsWidget::isPortrait();
     m_isDialogActive = false;
@@ -138,6 +139,8 @@ LsWidget* LockScreen::createWidget(QString type, QString name)
         return new LsBattery(name);
     else if (type == "UnlockButton")
         return new LsUnlockButton(name);
+    //else if (type == "SlideToUnlockButton")
+    //    return new LsSlideToUnlock(name);
     else if (type == "MediaPlayPauseButton")
         return new LsMediaPlayPauseButton(name, m_Player);
     else if (type == "MediaNextButton")
@@ -212,6 +215,8 @@ void LockScreen::onDisplayStateChangedSlot(QString displayState)
 #ifdef Q_WS_MAEMO_5
     qDebug() << "Display state changed:" << displayState;
     if (displayState == QLatin1String(MCE_DISPLAY_OFF_STRING)) {
+        if (m_tklockState == MCE_TK_LOCKED)
+            show();
         stopUpdate();
     }else if (displayState == QLatin1String(MCE_DISPLAY_ON_STRING)) {
         if (m_tklockState == MCE_TK_LOCKED && !m_isDialogActive){
