@@ -48,7 +48,7 @@ private:
     void createWidgets();
     void deleteWidgets();    
 
-    bool m_isCallActive;
+    bool m_isDialogActive;
     QString m_tklockState;
 
     void startUpdate();
@@ -64,6 +64,7 @@ private slots:
     void onOrientationChanged(int);
 #ifdef Q_WS_MAEMO_5
     void onIncomingCallSlot(QDBusMessage);
+    void onAlarmDialogStatusChanged(QDBusMessage);
 #endif
 };
 
