@@ -62,12 +62,16 @@ int main(int argc, char *argv[])
 
     QSettings().setDefaultFormat(QSettings::IniFormat);
     QString name = QSettings().fileName();
-    if (!QFile().exists(name)){
-        QFileInfo pathInfo(name);
-        if (!QDir().exists(pathInfo.path()))
-            QDir().mkpath(pathInfo.path());
+    QFileInfo pathInfo(name);
+    if (!QDir().exists(pathInfo.path()))
+        QDir().mkpath(pathInfo.path());
+
+    //Always copy the default current settings:
+    QFile().copy(":/DefaultSettings.conf", QString("%1.default").arg(name));
+
+    //Copy the default settings if the file does not exists.
+    if (!QFile().exists(name))
         QFile().copy(":/DefaultSettings.conf", name);
-    }
 
     QString locale = QLocale::system().name();
     qDebug() << "Locale:" << locale;
@@ -75,6 +79,7 @@ int main(int argc, char *argv[])
     if (translator.load(QString(":/qtlockscreen_%1").arg(locale)))
         a.installTranslator(&translator);
 
+    qDebug() << a.applicationName() << a.applicationVersion();
     LockScreen l;
 
     if (LockScreen::Debug || LockScreen::isLocked())
