@@ -72,11 +72,12 @@ void LsMediaMetadata::stopUpdate()
 void LsMediaMetadata::startUpdate()
 {
     if (m_Player){
+        m_Player->getCurrentMetadata();
         connect(m_Player, SIGNAL(metadataChanged(QMap<QString,QVariant>)), this, SLOT(onMetadataChanged(QMap<QString,QVariant>)));
-        if (m_Player->state() == SystemPlayer::UnknownState ||
+        /*if (m_Player->state() == SystemPlayer::UnknownState ||
             m_Player->state() == SystemPlayer::StoppedState){
 
-        }
+        }*/
     }
 }
 
