@@ -65,6 +65,9 @@ void LsNotification::applySettings()
     }else if (type == "email"){
         m_Type = NotificationNewEmail;
         defName = ":/images/email.png";
+    }else if (type == "im"){
+        m_Type = NotificationNewChat;
+        defName = ":/images/message.png";
     }
 
     m_Icon = QPixmap(getSetting("Icon", defName).toString());
@@ -88,6 +91,7 @@ void LsNotification::updateNotification()
     int sms = 0;
     int email = 0;
     int call = 0;
+    int chat = 0;
 
 #ifdef Q_WS_MAEMO_5
     if (m_Db.isOpen()){
@@ -106,13 +110,20 @@ void LsNotification::updateNotification()
                     rec = qry.record();
                     QString name = rec.value(0).toString();
                     qDebug() << name << rec.value(2).toInt();
-
+                    //sms-message
+                    //auth-request
+                    //chat-invitation
+                    //missed-call
+                    //email-message
+                    //voice-mail
                     if (name == "email-message")
                         email = rec.value(2).toInt();
                     else if (name == "sms-message")
                         sms = rec.value(2).toInt();
                     else if (name == "missed-call")
                         call = rec.value(2).toInt();
+                    else if (name == "chat-invitation")
+                        chat = rec.value(2).toInt();
                 }
             }
         }
@@ -122,16 +133,19 @@ void LsNotification::updateNotification()
         sms = 1;
         email = 1;
         call = 1;
+        chat = 1;
     }
 #else
     sms = 1;
     email = 1;
     call = 1;
+    chat = 1;
 #endif
 
     qDebug() << "Emails:" << email;
     qDebug() << "Calls:" << call;
     qDebug() << "SMS:" << sms;
+    qDebug() << "IM:" << chat;
 
     int value = 0;
     switch (m_Type){
@@ -147,6 +161,10 @@ void LsNotification::updateNotification()
         value = email;
         m_Text = QObject::tr("%1 new emails").arg(value);
         break;
+    case NotificationNewChat:
+        value = chat;
+        m_Text = QObject::tr("%1 new IM").arg(value);
+        break;
     default:
         break;
     }
